@@ -46,6 +46,7 @@
 const struct value_string e1_driver_names[] = {
 	{ E1_DRIVER_USB, "usb" },
 	{ E1_DRIVER_VPAIR, "vpair" },
+	{ E1_DRIVER_DAHDI_TRUNKDEV, "dahdi-trunkdev" },
 	{ 0, NULL }
 };
 
@@ -75,6 +76,7 @@ static const struct osmo_stat_item_desc line_stat_description[] = {
 	[LINE_GPSDO_TUNE_COARSE]= { "gpsdo:tune:coarse", "GSPDO Coarse Tuning" },
 	[LINE_GPSDO_TUNE_FINE]	= { "gpsdo:tune:fine", "GSPDO Fine Tuning" },
 	[LINE_GPSDO_FREQ_EST]	= { "gpsdo:freq_est", "GSPDO Frequency Estimate" },
+	[LINE_GPSDO_ERR_ACC]    = { "gpsdo:err_acc", "GPSDO Accumulated Error" },
 };
 
 static const struct osmo_stat_item_group_desc line_stats_desc = {
@@ -132,6 +134,22 @@ e1d_find_intf_by_usb_serial(struct e1_daemon *e1d, const char *serial_str)
 	return NULL;
 }
 
+struct e1_intf *
+e1d_find_intf_by_trunkdev_name(struct e1_daemon *e1d, const char *name)
+{
+	struct e1_intf *intf;
+
+	if (!name)
+		return NULL;
+
+	llist_for_each_entry(intf, &e1d->interfaces, list) {
+		if (intf->dahdi_trunkdev.name && !strcmp(intf->dahdi_trunkdev.name, name))
+			return intf;
+	}
+
+	return NULL;
+}
+
 struct e1_line *
 e1_intf_find_line(struct e1_intf *intf, uint8_t id)
 {
@@ -299,6 +317,11 @@ static struct octoi_client *octoi_client_by_line(struct e1_line *line)
 			    line->id == acc->u.ice1usb.line_nr)
 				return clnt;
 			break;
+		case ACCOUNT_MODE_DAHDI_TRUNKDEV:
+			if (!strcmp(line->intf->dahdi_trunkdev.name, acc->u.dahdi_trunkdev.name) &&
+			    line->id == acc->u.dahdi_trunkdev.line_nr)
+				return clnt;
+			break;
 		case ACCOUNT_MODE_NONE:
 		case ACCOUNT_MODE_REDIRECT:
 			break;
